The cheapest way to check that a key works.
Arguments
- key
Your API key. Defaults to the
DATARECEIPT_API_KEYenvironment variable; seedatareceipt_api_key().
The cheapest way to check that a key works.
Your API key. Defaults to the DATARECEIPT_API_KEY environment
variable; see datareceipt_api_key().